/* 
CreateVMRAndIIHCAndAutoTALAndMNI_BV23.js
Script to create an anatomical document in MNI space in BrainVoyager 23 from DICOM or NIfTI source based on the Getting Started Guide 4.0 data.
Latest update: 09-02-24
*/

var ObjectsRawDataPath = BrainVoyager.PathToSampleData + "ObjectsDicomGSG/";

function CreateVMR()
{
    var docVMR = BrainVoyager.CreateDocumentVMR( "DICOM", ObjectsRawDataPath + "RawData/BetSog_20040312_Goebel_C2 -0002-0001-00001.dcm", 192, false, 256, 256, 2 );
    if(docVMR != null)
        docVMR.SaveAs( ObjectsRawDataPath + "CG_3DT1MPR_SCRIPT.vmr" );
    return docVMR;
}

function IIHC()
{
    var ok;
    var docVMR = BrainVoyager.ActiveDocument;
    var success = docVMR.CorrectIntensityInhomogeneities();
    BrainVoyager.PrintToLog("Correcting intensity inhomogeneity (B1) succeeded: " + success);
}

function AutoACPCAndTAL()
{
    var ok;
    var docVMR = BrainVoyager.ActiveDocument;
    docVMR.AutoACPCAndTALTransformation();
}

function normaliseToMNISpace()
{
    var ok;
    var docVMR = BrainVoyager.ActiveDocument;
    var success = docVMR.NormalizeToMNISpace(); 
}

//var docVMR = CreateVMR(); // create anatomical document from DICOM data
var anatName = BrainVoyager.BrowseFile("Please select the anatomical file", "*.nii.gz"); // GSG4 data: path + "ses-04/anat/sub-01_ses-04_acq-nondistorted_T1w.nii.gz"
var docVMR = BrainVoyager.OpenDocument(anatName);
if (docVMR != null) {
    IIHC();
    // AutoACPCAndTAL();
    normaliseToMNISpace();
}

// Final name and path: ".../GSGData/derivatives/rawdata_bv/sub-01/ses-04/anat/sub-01_ses-04_acq-nondistorted_T1w_IIHC_MNI.vmr"
